==> apache-camel-quarkus-2.13.3-src.zip: camel-quarkus-2.13.3/integration-tests/saga/src/main/java/org/apache/camel/quarkus/component/saga/it/CreditService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.saga.it;

import java.util.HashMap;
import java.util.Map;

import javax.enterprise.context.ApplicationScoped;

import io.quarkus.runtime.annotations.RegisterForReflection;
import org.apache.camel.Header;

@ApplicationScoped
@RegisterForReflection
public class CreditService {

    private int totalCredit;

    private Map<String, Integer> reservations = new HashMap<>();

    public CreditService() {
        this.totalCredit = 100;
    }

    public synchronized void reserveCredit(String id, @Header("amount") int amount) {
        int credit = getCredit();
        if (amount > credit) {
            throw new IllegalStateException("Insufficient credit");
        }
        reservations.put(id, amount);
    }

    public synchronized void refundCredit(String id) {
        reservations.remove(id);
    }

    public synchronized int getCredit() {
        return totalCredit - reservations.values().stream().reduce(0, (a, b) -> a + b);
    }
}

==> apache-camel-quarkus-3.27.1-src.zip: camel-quarkus-3.27.1/integration-tests/saga/src/main/java/org/apache/camel/quarkus/component/saga/it/CreditService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.saga.it;

import java.util.HashMap;
import java.util.Map;

import io.quarkus.runtime.annotations.RegisterForReflection;
import jakarta.enterprise.context.ApplicationScoped;
import org.apache.camel.Header;

@ApplicationScoped
@RegisterForReflection
public class CreditService {

    private int totalCredit;

    private Map<String, Integer> reservations = new HashMap<>();

    public CreditService() {
        this.totalCredit = 100;
    }

    public synchronized void reserveCredit(String id, @Header("amount") int amount) {
        int credit = getCredit();
        if (amount > credit) {
            throw new IllegalStateException("Insufficient credit");
        }
        reservations.put(id, amount);
    }

    public synchronized void refundCredit(String id) {
        reservations.remove(id);
    }

    public synchronized int getCredit() {
        return totalCredit - reservations.values().stream().reduce(0, (a, b) -> a + b);
    }
}
